==> adams-video-0.4.11-sources.jar: adams/gui/visualization/trail/TrailContainerManager.java <==
/*
 *   This program is free software: you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation, either version 3 of the License, or
 *   (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

/**
 * TrailContainerManager.java
 * Copyright (C) 2015 University of Waikato, Hamilton, New Zealand
 */
package adams.gui.visualization.trail;

import adams.data.trail.Trail;
import adams.gui.visualization.container.AbstractContainerManager;
import adams.gui.visualization.container.NamedContainerManager;

/**
 * Container manager for trails.
 *
 * @author  fracpete (fracpete at waikato dot ac dot nz)
 * @version $Revision: 11342 $
 */
public class TrailContainerManager
  extends AbstractContainerManager<TrailContainer>
  implements NamedContainerManager {

  /** for serialization. */
  private static final long serialVersionUID = 189470224357901714L;

  /**
   * Returns the index of the first ID or display ID that matches the
   * specified one.
   *
   * @param id	the ID/display ID to look for
   * @return		the index or -1 if not found
   */
  public int indexOf(String id) {
    int		result;
    int		i;

    result = -1;

    for (i = 0; i < count(); i++) {
      if (get(i).getID().equals(id)) {
	result = i;
	break;
      }
    }

    return result;
  }

  /**
   * Returns a new container containing the given payload.
   *
   * @param o		the payload to encapsulate
   * @return		the new container
   */
  @Override
  public TrailContainer newContainer(Comparable o) {
    return new TrailContainer(this, (Trail) o);
  }
}

==> adams-video-16.12.1-sources.jar: adams/gui/visualization/trail/TrailContainerManager.java <==
/*
 *   This program is free software: you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation, either version 3 of the License, or
 *   (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

/**
 * TrailContainerManager.java
 * Copyright (C) 2015 University of Waikato, Hamilton, New Zealand
 */
package adams.gui.visualization.trail;

import adams.data.trail.Trail;
import adams.gui.visualization.container.AbstractContainerManager;
import adams.gui.visualization.container.NamedContainerManager;

/**
 * Container manager for trails.
 *
 * @author  fracpete (fracpete at waikato dot ac dot nz)
 * @version $Revision: 14984 $
 */
public class TrailContainerManager
  extends AbstractContainerManager<TrailContainer>
  implements NamedContainerManager {

  /** for serialization. */
  private static final long serialVersionUID = 189470224357901714L;

  /**
   * Returns the index of the first ID or display ID that matches the
   * specified one.
   *
   * @param id	the ID/display ID to look for
   * @return		the index or -1 if not found
   */
  public int indexOf(String id) {
    int		result;
    int		i;

    result = -1;

    for (i = 0; i < count(); i++) {
      if (get(i).getID().equals(id)) {
	result = i;
	break;
      }
    }

    return result;
  }

  /**
   * Returns a new container containing the given payload.
   *
   * @param o		the payload to encapsulate
   * @return		the new container
   */
  @Override
  public TrailContainer newContainer(Comparable o) {
    return new TrailContainer(this, (Trail) o);
  }

  /**
   * Returns whether the container matches the current search.
   *
   * @param cont	the container to check
   * @param search	the search string
   * @param regExp	whether to perform regular expression matching
   */
  @Override
  protected boolean isMatch(TrailContainer cont, String search, boolean regExp) {
    if (regExp)
      return cont.getID().matches(search);
    else
      return cont.getID().toLowerCase().contains(search);
  }
}
